package recipe

import (
	"coopcloud.tech/abra/cli/formatter"
	"coopcloud.tech/abra/cli/internal"
	"coopcloud.tech/abra/pkg/catalogue"
	"github.com/sirupsen/logrus"
	"github.com/urfave/cli/v2"
)

var recipeVersionCommand = &cli.Command{
	Name:      "versions",
	Usage:     "List recipe versions",
	Aliases:   []string{"v"},
	ArgsUsage: "<recipe>",
	Action: func(c *cli.Context) error {
		recipe := internal.ValidateRecipe(c)

		catalogue, err := catalogue.ReadRecipeCatalogue()
		if err != nil {
			logrus.Fatal(err)
		}

		recipeMeta, ok := catalogue[recipe.Name]
		if !ok {
			logrus.Fatalf("'%s' recipe doesn't exist?", recipe.Name)
		}

		tableCol := []string{"Version", "Service", "Image", "Digest"}
		table := formatter.CreateTable(tableCol)

		for version := range recipeMeta.Versions {
			for service := range recipeMeta.Versions[version] {
				meta := recipeMeta.Versions[version][service]
				table.Append([]string{version, service, meta.Image, meta.Digest})
			}
		}

		table.SetAutoMergeCells(true)
		table.Render()

		return nil
	},
}
